@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -38,7 +38,7 @@ FilterActionAddHeaderTest::~FilterActionAddHeaderTest()
 void FilterActionAddHeaderTest::shouldCreateWidget()
 {
     MailCommon::FilterActionAddHeader filter;
-    QWidget *widget = filter.createParamWidget(0);
+    QWidget *widget = filter.createParamWidget(nullptr);
     QVERIFY(widget);
     PimCommon::MinimumComboBox *comboBox = widget->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("combo"));
     QVERIFY(comboBox);
@@ -63,7 +63,7 @@ void FilterActionAddHeaderTest::shouldAddValue_data()
 void FilterActionAddHeaderTest::shouldClearWidget()
 {
     MailCommon::FilterActionAddHeader filter;
-    QWidget *widget = filter.createParamWidget(0);
+    QWidget *widget = filter.createParamWidget(nullptr);
     PimCommon::MinimumComboBox *comboBox = widget->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("combo"));
     KLineEdit *lineEdit = widget->findChild<KLineEdit *>(QStringLiteral("ledit"));
     comboBox->lineEdit()->setText(QStringLiteral("test"));
@@ -76,7 +76,7 @@ void FilterActionAddHeaderTest::shouldClearWidget()
 void FilterActionAddHeaderTest::shouldReturnSieveCode()
 {
     MailCommon::FilterActionAddHeader filter;
-    QCOMPARE(filter.sieveRequires().join(QStringLiteral(",")), QStringLiteral("editheader"));
+    QCOMPARE(filter.sieveRequires().join(QLatin1Char(',')), QStringLiteral("editheader"));
 }
 
 void FilterActionAddHeaderTest::shouldBeEmpty()
@@ -197,7 +197,7 @@ void FilterActionAddHeaderTest::shouldAddValue()
     QFETCH(QString, resultvalue);
 
     MailCommon::FilterActionAddHeader filter;
-    QWidget *widget = filter.createParamWidget(0);
+    QWidget *widget = filter.createParamWidget(nullptr);
     filter.argsFromString(argsinput);
     filter.setParamWidgetValue(widget);
     PimCommon::MinimumComboBox *comboBox = widget->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("combo"));
