@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -39,7 +39,7 @@ FilterActionMissingIdentityDialogTest::~FilterActionMissingIdentityDialogTest()
 
 void FilterActionMissingIdentityDialogTest::initTestCase()
 {
-    DummyKernel *kernel = new DummyKernel(0);
+    DummyKernel *kernel = new DummyKernel(nullptr);
     CommonKernel->registerKernelIf(kernel);   //register KernelIf early, it is used by the Filter classes
     CommonKernel->registerSettingsIf(kernel);   //SettingsIf is used in FolderTreeWidget
 }
