@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,7 +31,7 @@ public:
     explicit FilterActionMissingTagDialog(const QMap<QUrl, QString> &templateList,
                                           const QString &filtername,
                                           const QString &argsStr,
-                                          QWidget *parent = Q_NULLPTR);
+                                          QWidget *parent = nullptr);
     ~FilterActionMissingTagDialog();
     QString selectedTag() const;
 
