@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,7 +31,7 @@ class FilterActionMissingTemplateDialog : public QDialog
 public:
     explicit FilterActionMissingTemplateDialog(const QStringList &templateList,
             const QString &filtername,
-            QWidget *parent = Q_NULLPTR);
+            QWidget *parent = nullptr);
     ~FilterActionMissingTemplateDialog();
     QString selectedTemplate() const;
 
