@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -33,7 +33,7 @@ class SelectThunderbirdFilterFilesWidget : public QWidget
     Q_OBJECT
 
 public:
-    explicit SelectThunderbirdFilterFilesWidget(const QString &defaultSettingPath, QWidget *parent = Q_NULLPTR);
+    explicit SelectThunderbirdFilterFilesWidget(const QString &defaultSettingPath, QWidget *parent = nullptr);
     ~SelectThunderbirdFilterFilesWidget();
     QStringList selectedFiles() const;
 
