@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -74,7 +74,7 @@ void FilterTestKernel::syncConfig()
 MailCommon::JobScheduler *FilterTestKernel::jobScheduler() const
 {
     Q_ASSERT(false);
-    return 0;
+    return nullptr;
 }
 
 Akonadi::ChangeRecorder *FilterTestKernel::folderCollectionMonitor() const
