@@ -103,12 +103,12 @@ void FilterImporterExporter::writeFiltersToConfig(const QList<MailFilter *> &fil
     const QStringList filterGroups =
         config->groupList().filter(QRegularExpression(QStringLiteral("Filter #\\d+")));
 
-    foreach (const QString &group, filterGroups) {
+    for (const QString &group : filterGroups) {
         config->deleteGroup(group);
     }
 
     int i = 0;
-    foreach (const MailFilter *filter, filters) {
+    for (const MailFilter *filter : filters) {
         if (!filter->isEmpty()) {
             const QString groupName = QStringLiteral("Filter #%1").arg(i);
 
@@ -236,7 +236,8 @@ QList<MailFilter *> FilterImporterExporter::importFilters(
             SelectThunderbirdFilterFilesDialog *selectThunderBirdFileDialog = new SelectThunderbirdFilterFilesDialog(defaultPath, d->mParent);
             selectThunderBirdFileDialog->setStartDir(QUrl::fromLocalFile(defaultPath));
             if (selectThunderBirdFileDialog->exec()) {
-                Q_FOREACH (const QString &url, selectThunderBirdFileDialog->selectedFiles()) {
+                const QStringList lstFiles = selectThunderBirdFileDialog->selectedFiles();
+                for (const QString &url : lstFiles ) {
                     QFile fileThunderbird(url);
                     if (!fileThunderbird.open(QIODevice::ReadOnly)) {
                         KMessageBox::error(
@@ -363,7 +364,7 @@ void FilterImporterExporter::exportFilters(const QList<MailFilter *> &filters, c
         writeFiltersToConfig(filters, config, true);
         //qDeleteAll(filters);
     } else {
-        QScopedPointer<FilterSelectionDialog> dlg(new FilterSelectionDialog(d->mParent));
+        std::unique_ptr<FilterSelectionDialog> dlg(new FilterSelectionDialog(d->mParent));
         dlg->setFilters(filters);
         if (dlg->exec() == QDialog::Accepted && dlg) {
             QList<MailFilter *> lst = dlg->selectedFilters();
