@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,7 @@
 #ifndef INVALIDFILTERDIALOG_H
 #define INVALIDFILTERDIALOG_H
 
-#include "mailcommon_export.h"
+#include "mailcommon_private_export.h"
 #include "invalidfilterinfo.h"
 #include <QDialog>
 
@@ -26,11 +26,11 @@ namespace MailCommon
 {
 class InvalidFilterWidget;
 class InvalidFilterInfoWidget;
-class MAILCOMMON_EXPORT InvalidFilterDialog : public QDialog
+class MAILCOMMON_TESTS_EXPORT InvalidFilterDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit InvalidFilterDialog(QWidget *parent = Q_NULLPTR);
+    explicit InvalidFilterDialog(QWidget *parent = nullptr);
     ~InvalidFilterDialog();
 
     void setInvalidFilters(const QVector<InvalidFilterInfo> &lst);
