@@ -41,7 +41,7 @@ public:
      *
      * @param parent The parent widget.
      */
-    explicit SoundTestWidget(QWidget *parent = Q_NULLPTR);
+    explicit SoundTestWidget(QWidget *parent = nullptr);
 
     /**
      * Destroys the sound test widget.
