@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -25,7 +25,7 @@ class FilterImporterExporterGui : public QWidget
 {
     Q_OBJECT
 public:
-    explicit FilterImporterExporterGui(QWidget *parent = Q_NULLPTR);
+    explicit FilterImporterExporterGui(QWidget *parent = nullptr);
     ~FilterImporterExporterGui();
 private Q_SLOTS:
     void slotImportFilter(QAction *act);
