@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -47,9 +47,9 @@ class Q_DECL_HIDDEN FolderSelectionDialog::FolderSelectionDialogPrivate
 {
 public:
     FolderSelectionDialogPrivate()
-        : folderTreeWidget(0),
-          mUser1Button(0),
-          mOkButton(0),
+        : folderTreeWidget(nullptr),
+          mUser1Button(nullptr),
+          mOkButton(nullptr),
           mNotAllowToCreateNewFolder(false),
           mUseGlobalSettings(true)
     {
@@ -67,7 +67,7 @@ FolderSelectionDialog::FolderSelectionDialog(QWidget *parent, SelectionFolderOpt
     setObjectName(QStringLiteral("folder dialog"));
 
     d->mNotAllowToCreateNewFolder = (options & FolderSelectionDialog::NotAllowToCreateNewFolder);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QVBoxLayout *mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -104,7 +104,7 @@ FolderSelectionDialog::FolderSelectionDialog(QWidget *parent, SelectionFolderOpt
         optReadableProxy |= FolderTreeWidgetProxyModel::HideOutboxFolder;
     }
 
-    d->folderTreeWidget = new FolderTreeWidget(this, 0, opt, optReadableProxy);
+    d->folderTreeWidget = new FolderTreeWidget(this, nullptr, opt, optReadableProxy);
     d->folderTreeWidget->readConfig();
     d->folderTreeWidget->disableContextMenuAndExtraColumn();
     d->folderTreeWidget->folderTreeWidgetProxyModel()->setEnabledCheck((options & EnableCheck));
@@ -159,7 +159,7 @@ void FolderSelectionDialog::slotDoubleClick(const QModelIndex &index)
 {
     Q_UNUSED(index);
     const bool hasSelectedCollection =
-        (d->folderTreeWidget->selectionModel()->selectedIndexes().count() > 0);
+        (!d->folderTreeWidget->selectionModel()->selectedIndexes().isEmpty());
     if (hasSelectedCollection) {
         accept();
     }
@@ -233,7 +233,7 @@ void FolderSelectionDialog::collectionCreationResult(KJob *job)
 void FolderSelectionDialog::slotSelectionChanged()
 {
     const bool enablebuttons =
-        (d->folderTreeWidget->selectionModel()->selectedIndexes().count() > 0);
+        (!d->folderTreeWidget->selectionModel()->selectedIndexes().isEmpty());
     d->mOkButton->setEnabled(enablebuttons);
 
     if (!d->mNotAllowToCreateNewFolder) {
