@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -23,7 +23,7 @@
 #include "kernel/mailkernel.h"
 #include "util/mailutil.h"
 
-#include <PimCommon/ImapAclAttribute>
+#include <PimCommonAkonadi/ImapAclAttribute>
 #include <PimCommon/PimUtil>
 
 #include <AkonadiCore/AttributeFactory>
@@ -58,14 +58,14 @@ class Q_DECL_HIDDEN FolderTreeWidget::FolderTreeWidgetPrivate
 {
 public:
     FolderTreeWidgetPrivate()
-        : filterModel(0),
-          folderTreeView(0),
-          quotaModel(0),
-          readableproxy(0),
-          entityOrderProxy(0),
-          filterFolderLineEdit(0),
-          saver(0),
-          label(0),
+        : filterModel(nullptr),
+          folderTreeView(nullptr),
+          quotaModel(nullptr),
+          readableproxy(nullptr),
+          entityOrderProxy(nullptr),
+          filterFolderLineEdit(nullptr),
+          saver(nullptr),
+          label(nullptr),
           dontKeyFilter(false)
     {
     }
@@ -239,7 +239,7 @@ Akonadi::Collection::List FolderTreeWidget::selectedCollections() const
     Akonadi::Collection::List collections;
     const QItemSelectionModel *selectionModel = d->folderTreeView->selectionModel();
     const QModelIndexList selectedIndexes = selectionModel->selectedIndexes();
-    foreach (const QModelIndex &index, selectedIndexes) {
+    for (const QModelIndex &index : selectedIndexes) {
         if (index.isValid()) {
             const Akonadi::Collection collection =
                 index.model()->data(
