@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -57,7 +57,7 @@ QWidget *HeadersRuleWidgetHandler::createFunctionWidget(
     int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const
 {
     if (number != 0) {
-        return 0;
+        return nullptr;
     }
 
     PimCommon::MinimumComboBox *funcCombo = new PimCommon::MinimumComboBox(functionStack);
@@ -99,7 +99,7 @@ QWidget *HeadersRuleWidgetHandler::createValueWidget(int number,
         label->setBuddy(valueStack);
         return label;
     }
-    return 0;
+    return nullptr;
 }
 
 //---------------------------------------------------------------------------
