@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,13 +19,13 @@
 
 #include <KConfig>
 
-using namespace PimCommon;
+using namespace MailCommon;
 
-class PimCommon::ResourceReadConfigFilePrivate
+class MailCommon::ResourceReadConfigFilePrivate
 {
 public:
     ResourceReadConfigFilePrivate()
-        : mConfig(Q_NULLPTR)
+        : mConfig(nullptr)
     {
 
     }
@@ -38,7 +38,7 @@ public:
 };
 
 ResourceReadConfigFile::ResourceReadConfigFile(const QString &resourceName)
-    : d(new PimCommon::ResourceReadConfigFilePrivate)
+    : d(new MailCommon::ResourceReadConfigFilePrivate)
 {
     d->mConfig = new KConfig(resourceName + QStringLiteral("rc"));
 }
