@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -38,8 +38,8 @@ class Q_DECL_HIDDEN FavoriteCollectionWidget::Private
 {
 public:
     Private()
-        : listMode(0),
-          iconMode(0)
+        : listMode(nullptr),
+          iconMode(nullptr)
     {
     }
     QColor textColor;
@@ -72,7 +72,7 @@ FavoriteCollectionWidget::~FavoriteCollectionWidget()
 void FavoriteCollectionWidget::mousePressEvent(QMouseEvent *e)
 {
     const bool buttonPressedIsMiddle = (e->button() == Qt::MidButton);
-    Q_EMIT prefereCreateNewTab(buttonPressedIsMiddle);
+    Q_EMIT newTabRequested(buttonPressedIsMiddle);
     Akonadi::EntityListView::mousePressEvent(e);
 }
 
@@ -100,7 +100,7 @@ void FavoriteCollectionWidget::createMenu(KActionCollection *ac)
 
     QActionGroup *grp = new QActionGroup(iconSizeMenu);
     const int nbElement((int)(sizeof(icon_sizes) / sizeof(int)));
-    QAction *act = Q_NULLPTR;
+    QAction *act = nullptr;
     for (int i = 0; i < nbElement; ++i) {
         act = new QAction(QStringLiteral("%1x%2").arg(icon_sizes[ i ]).arg(icon_sizes[ i ]), iconSizeMenu);
         iconSizeMenu->addAction(act);
